Module parser

Module parser 

Structs

ComponentImport
Document
Element
FnccParser

Enums

AttrValue
ImportSource
Node
Rule

Functions

collect_commands
Collect all command names referenced via onclick attributes in an element tree.
get_condition_attr
Get the condition attribute value from an <If> or <ElseIf> element.
get_each_attr
Get the each attribute value from a <For> element.
get_index_attr
Get the index attribute value from a <For> element.
get_let_attr
Get the let attribute value from a <For> element.
has_slot
Check if an element tree contains a <Slot> element.
parse
uses_props_interpolation
Check whether an element tree contains {props.field} interpolation. Used to determine if a component actually receives props (vs merely referencing a PropsType import for a child component).