pub struct RouteInfo {
pub relative_path: PathBuf,
pub file_path: PathBuf,
pub pattern: String,
pub variant_name: String,
pub params: Vec<String>,
pub layout_chain: Vec<PathBuf>,
pub is_fallback: bool,
}Expand description
Information about a single route discovered by scanning the routes directory.
Fields
relative_path: PathBufRelative path from the routes root directory (e.g., “users/[id].fui”).
file_path: PathBufAbsolute file path to the .fui file.
pattern: StringCanonical URL pattern (e.g., “/”, “/settings”, “/users/:id”).
variant_name: StringGenerated PascalCase enum variant name (e.g., “Index”, “Settings”, “UsersId”).
params: Vec<String>Dynamic parameter names extracted from path segments (e.g., [“id”]).
layout_chain: Vec<PathBuf>Relative paths to layout files wrapping this route, from outer to inner.
is_fallback: boolTrue if this is the application fallback screen (fallback.fui).
Implementations