Functions
- generate
- generate_
with_ id - generate_
with_ imports - Generate code for a document with a specific component name.
component_nameis used for the render function name (derived from the file stem). IfNone, falls back to the root element name (backward compat).resolved_state_typeoverrides the document’s@statedirective (used by semantic analysis). - generate_
with_ imports_ and_ route_ params
Type Aliases
- Resolved
Import - Resolved import entry: (tag_name, render_fn_name)