Module parser

Module parser 

Structs

ComponentImport
Document
Element
FnccParser

Enums

AttrValue
ImportSource
Node
Rule

Functions

collect_commands
Collect all command names referenced via onclick attributes in an element tree.
parse
uses_props_interpolation
Check whether an element tree contains {props.field} interpolation. Used to determine if a component actually receives props (vs merely referencing a PropsType import for a child component).